/*
 This file is part of Ubuntu-it Menu.

 Ubuntu-it Menu is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 2 of the License, or
 (at your option) any later version.

 Ubuntu-it Menu is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with Ubuntu-it Menu.  If not, see http://www.gnu.org/licenses/.

 The copy of the GNU General Public License can be found here:
 chrome://ubuntuit/locale/GPLv2License.txt
*/
pref('extensions.{3179072b-597c-4f4d-827b-9f49a228fcdc}.description','chrome://ubuntuit/locale/ubuntuit.properties');
pref('extensions.ubuntuit.TitleMenu', true);
pref('extensions.ubuntuit.ToolsMenu', true);
pref('extensions.ubuntuit.ContextMenu', true);
pref('extensions.ubuntuit.ShowLogo', true);
pref('extensions.ubuntuit.HomeLink', true);
pref('extensions.ubuntuit.SearchLink', true);
pref('extensions.ubuntuit.MainMenu', true);
pref('extensions.ubuntuit.WikiMenu', true);
pref('extensions.ubuntuit.IrcMenu', true);
pref('extensions.ubuntuit.MailMenu', true);
pref('extensions.ubuntuit.UtiliMenu', true);
pref('extensions.ubuntuit.ForumMenu', true);
pref('extensions.ubuntuit.Options', true);
pref('extensions.ubuntuit.DerLinks', 'Kub,Edub,Xub,');
pref('extensions.ubuntuit.IntLinks', 'INT,FR,DE,ES,');
pref('extensions.ubuntuit.PersForumMenu', true);
pref('extensions.ubuntuit.ForumForumMenu', true);
pref('extensions.ubuntuit.SectionsForumMenu', true);
pref('extensions.ubuntuit.myWikiHomepage', '');
pref('extensions.ubuntuit.myIntWikiHomepage', '');
pref('extensions.ubuntuit.myLPHomepage', '');
